summaryrefslogtreecommitdiffstats
path: root/arch/m68k/lib
diff options
context:
space:
mode:
Diffstat (limited to 'arch/m68k/lib')
-rw-r--r--arch/m68k/lib/Makefile10
-rw-r--r--arch/m68k/lib/barebox.lds.S (renamed from arch/m68k/lib/u-boot.lds.S)26
-rw-r--r--arch/m68k/lib/m68k-linuxboot.c10
-rw-r--r--arch/m68k/lib/m68k-meminit.c10
-rw-r--r--arch/m68k/lib/m68k-module.c8
5 files changed, 32 insertions, 32 deletions
diff --git a/arch/m68k/lib/Makefile b/arch/m68k/lib/Makefile
index 52ea7e9542..09cfb29848 100644
--- a/arch/m68k/lib/Makefile
+++ b/arch/m68k/lib/Makefile
@@ -2,20 +2,20 @@
# (C) Copyright 2007 Carsten Schlote <schlote@vahanus.net>
# See file CREDITS for list of people who contributed to this project.
#
-# This file is part of U-Boot V2.
+# This file is part of barebox.
#
-# U-Boot V2 is free software: you can redistribute it and/or modify
+# barebox is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
-# U-Boot V2 is distributed in the hope that it will be useful,
+# barebox is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with U-Boot V2. If not, see <http://www.gnu.org/licenses/>.
+# along with barebox. If not, see <http://www.gnu.org/licenses/>.
#
#
@@ -28,4 +28,4 @@ obj-$(CONFIG_CMD_BOOTM) += m68k-linuxboot.o
obj-$(CONFIG_MODULES) += m68k-module.o
-extra-$(CONFIG_GENERIC_LINKER_SCRIPT) += u-boot.lds
+extra-$(CONFIG_GENERIC_LINKER_SCRIPT) += barebox.lds
diff --git a/arch/m68k/lib/m68k-linuxboot.c b/arch/m68k/lib/m68k-linuxboot.c
index b29e2d5c13..417a8e0cd7 100644
--- a/arch/m68k/lib/m68k-linuxboot.c
+++ b/arch/m68k/lib/m68k-linuxboot.c
@@ -2,20 +2,20 @@
* Copyright (c) 2008 Carsten Schlote <c.schlote@konzeptpark.de>
* See file CREDITS for list of people who contributed to this project.
*
- * This file is part of U-Boot V2.
+ * This file is part of barebox.
*
- * U-Boot V2 is free software: you can redistribute it and/or modify
+ * barebox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * U-Boot V2 is distributed in the hope that it will be useful,
+ * barebox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with U-Boot V2. If not, see <http://www.gnu.org/licenses/>.
+ * along with barebox. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
@@ -37,7 +37,7 @@
#include <asm/setup.h>
#include <environment.h>
#include <boot.h>
-#include <asm/u-boot-m68k.h>
+#include <asm/barebox-m68k.h>
#include <asm/bootinfo.h>
diff --git a/arch/m68k/lib/m68k-meminit.c b/arch/m68k/lib/m68k-meminit.c
index 8dfaa9c479..664ef509c5 100644
--- a/arch/m68k/lib/m68k-meminit.c
+++ b/arch/m68k/lib/m68k-meminit.c
@@ -2,20 +2,20 @@
* Copyright (c) 2008 Carsten Schlote <c.schlote@konzeptpark.de>
* See file CREDITS for list of people who contributed to this project.
*
- * This file is part of U-Boot V2.
+ * This file is part of barebox.
*
- * U-Boot V2 is free software: you can redistribute it and/or modify
+ * barebox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * U-Boot V2 is distributed in the hope that it will be useful,
+ * barebox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with U-Boot V2. If not, see <http://www.gnu.org/licenses/>.
+ * along with barebox. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
@@ -24,7 +24,7 @@
#include <common.h>
#include <init.h>
#include <mem_malloc.h>
-#include <asm/u-boot-m68k.h>
+#include <asm/barebox-m68k.h>
#include <reloc.h>
#include <asm-generic/memory_layout.h>
diff --git a/arch/m68k/lib/m68k-module.c b/arch/m68k/lib/m68k-module.c
index e1fe461a3a..6a4a2bc1c2 100644
--- a/arch/m68k/lib/m68k-module.c
+++ b/arch/m68k/lib/m68k-module.c
@@ -2,20 +2,20 @@
* Copyright (c) 2008 Carsten Schlote <c.schlote@konzeptpark.de>
* See file CREDITS for list of people who contributed to this project.
*
- * This file is part of U-Boot V2.
+ * This file is part of barebox.
*
- * U-Boot V2 is free software: you can redistribute it and/or modify
+ * barebox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * U-Boot V2 is distributed in the hope that it will be useful,
+ * barebox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with U-Boot V2. If not, see <http://www.gnu.org/licenses/>.
+ * along with barebox. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
diff --git a/arch/m68k/lib/u-boot.lds.S b/arch/m68k/lib/barebox.lds.S
index 823e17a9de..fb6673deec 100644
--- a/arch/m68k/lib/u-boot.lds.S
+++ b/arch/m68k/lib/barebox.lds.S
@@ -2,26 +2,26 @@
* Copyright (c) 2008 Carsten Schlote <c.schlote@konzeptpark.de>
* See file CREDITS for list of people who contributed to this project.
*
* This file is part of U-Boot V2.
*
* U-Boot V2 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* U-Boot V2 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with U-Boot V2. If not, see <http://www.gnu.org/licenses/>.
+ * along with barebox. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file
* Generic Linker file for M68k targets
*/
-#include <asm-generic/u-boot.lds.h>
+#include <asm-generic/barebox.lds.h>
OUTPUT_FORMAT("elf32-m68k", "elf32-m68k",
"elf32-m68k")
@@ -54,16 +54,16 @@ SECTIONS
} =0xdeadbeef
. = ALIGN(4);
- __u_boot_cmd_start = .;
- .u_boot_cmd : { U_BOOT_CMDS }
- __u_boot_cmd_end = .;
+ __barebox_cmd_start = .;
+ .barebox_cmd : { BAREBOX_CMDS }
+ __barebox_cmd_end = .;
- __u_boot_initcalls_start = .;
- .u_boot_initcalls : { INITCALLS }
- __u_boot_initcalls_end = .;
+ __barebox_initcalls_start = .;
+ .barebox_initcalls : { INITCALLS }
+ __barebox_initcalls_end = .;
__usymtab_start = .;
- __usymtab : { U_BOOT_SYMS }
+ __usymtab : { BAREBOX_SYMS }
__usymtab_end = .;
/* End of text and rodata section */
@@ -88,5 +88,5 @@ SECTIONS
_end = .;
. = ALIGN(4);
- _u_boot_heap_start = .;
+ _barebox_heap_start = .;
}
@@ -2,26 +2,26 @@
* See file CREDITS for list of people who contributed to this project.
*
- * This file is part of U-Boot V2.
+ * This file is part of barebox.
*
@@ -2,26 +2,26 @@
*
- * U-Boot V2 is free software: you can redistribute it and/or modify
+ * barebox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -2,26 +2,26 @@
* (at your option) any later version.
*
- * U-Boot V2 is distributed in the hope that it will be useful,
+ * barebox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the